==> igniteui-react-charts-18.5.1.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.bg = function () {
        return new SlowStochasticOscillatorIndicator();
    };
    SlowStochasticOscillatorIndicator.prototype.get_yz = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_zc = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zk", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.zl));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.zl, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.y5 = function () {
        return this.zk;
    };
    SlowStochasticOscillatorIndicator.prototype.ze = function (a) {
        this.zk = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.zl = StrategyBasedIndicator.zh(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };

==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.bc = function () {
        return new SlowStochasticOscillatorIndicator();
    };
    SlowStochasticOscillatorIndicator.prototype.get_y0 = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_zd = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "zl", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.zm));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.zm, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.y6 = function () {
        return this.zl;
    };
    SlowStochasticOscillatorIndicator.prototype.zf = function (a) {
        this.zl = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.zm = StrategyBasedIndicator.zi(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };
